@@ -356,7 +356,9 @@ start_information_print(){
     echo "  IMAGE_REGISTRY=$IMAGE_REGISTRY"|& tee -i -a $LOG
     fi
     if $RUN_AS_CONTAINER; then
-      if [[ -z "$EXISTING_AKS_RESOURCE_GROUP_NAME" ]]; then
+      if $MEDIAFIRST_INTEGRATION; then
+        RESOURCEGROUP_NAME="${CLUSTER_NAME}_K8S"
+      elif [[ -z "$EXISTING_AKS_RESOURCE_GROUP_NAME" ]]; then
         RESOURCEGROUP_NAME="rg-$CLUSTER_NAME"
       else
         RESOURCEGROUP_NAME="$EXISTING_AKS_RESOURCE_GROUP_NAME"
