@@ -618,7 +618,11 @@ function set_aks_cluster_name() {
 
 function set_azure_resource_group() {
   legacy_rg_name="$CLUSTER_NAME-cms-resourcegroup"
-  [ "$MEDIAFIRST_INTEGRATION" = false ] && new_rg_name="rg-$CLUSTER_NAME" || new_rg_name="${CLUSTER_NAME}_K8S"
+  if [ "$MEDIAFIRST_INTEGRATION" = false ]; then
+    new_rg_name="rg-${CLUSTER_NAME}"
+  else
+    new_rg_name="${CLUSTER_NAME}_K8S"
+  fi
 
   if grep -q "default[[:space:]]*= \"$legacy_rg_name\"" $TF_DEFAULT_VARIABLES; then
     # When using legacy resource groupname, it means the AKS cluster has been deployed
